@@ -1,29 +1,13 @@
 package LinkLocal::IPv4::Interface::Logger;
 
-our $VERSION = '0.19_01';
+our $VERSION = '0.16';
 
 require 5.010_000;
 
-# Copyright (C) 2010 Raymond Mroz, Tony Li Xu
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 use LinkLocal::IPv4::Interface::Types;
+use Sys::Syslog qw/ :standard :macros /;
 use Moose;
 use MooseX::Params::Validate;
-use Try::Tiny;
-use Sys::Syslog qw/ :standard :macros /;
 
 use feature ':5.10';
 
@@ -72,130 +56,75 @@ sub open_log {
         facility => { isa => 'Str', optional => 1, default => 'user' }
     );
 
-    try {
-        openlog( $params{indent}, $params{options}, $params{facility} );
-    }
-    catch {
-        die "Unable to open syslog instance for writing: $!";
-    };
+    openlog( $params{indent}, $params{options}, $params{facility} );
 }
 
 sub _set_log_mask {
     my $this = shift;
 
-    try {
-        setlogmask( ~( &Sys::Syslog::LOG_MASK(NOTICE) ) );
-    }
-    catch {
-        die "Error while setting log mask: $!";
-    };
+    setlogmask( ~( &Sys::Syslog::LOG_MASK(NOTICE) ) );
 }
 
 sub emerg {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'emerg', "%8s: %s", "Emerg", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'emerg', "%8s: %s", "Emerg", $message );
 }
 
 sub alert {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'alert', "%8s: %s", "Alert", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'alert', "%8s: %s", "Alert", $message );
 }
 
 sub critical {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'crit', "%8s: %s", "Critical", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'crit', "%8s: %s", "Critical", $message );
 }
 
 sub error {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'err', "%8s: %s", "Error", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'err', "%8s: %s", "Error", $message );
 }
 
 sub warning {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'warning', "%8s: %s", "Warning", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'warning', "%8s: %s", "Warning", $message );
 }
 
 sub notice {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'notice', "%8s: %s", "Notice", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'notice', "%8s: %s", "Notice", $message );
 }
 
 sub info {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'info', "%8s: %s", "Info", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'info', "%8s: %s", "Info", $message );
 }
 
 sub debug {
     my $this = shift;
     my ($message) = pos_validated_list( \@_, { isa => 'Str' } );
 
-    try {
-        syslog( 'debug', "%8s: %s", "Debug", $message );
-    }
-    catch {
-        die "Error while writing to syslog: $!";
-    };
+    syslog( 'debug', "%8s: %s", "Debug", $message );
 }
 
 sub close_log {
     my $this = shift;
 
-    try {
-        closelog();
-    }
-    catch {
-        die "Error while closing syslog: $!";
-    };
+    closelog();
 }
 
 no Moose;
@@ -302,7 +231,7 @@ class type.
 Refer to RFC-3927, I<Dynamic Configuration of IPv4 Link-Local Adresses>, the complete
 text of which can be found in the top level of the package archive.
 
-L<perl>, L<Moose>, L<MooseX::Params::Validate>, L<Sys::Syslog>, L<Try::Tiny>
+L<perl>, L<Moose>, L<MooseX::Params::Validate>, L<Sys::Syslog>
 
 This project is also hosted on github at:
 	git@github.com:raymroz/LinkLocal--IPv4.git
